==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/PreferencesFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PreferencesFluent<A extends io.fabric8.kubernetes.api.model.PreferencesFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Boolean getColors();
  public A withColors(java.lang.Boolean colors);
  public java.lang.Boolean hasColors();
  public A addToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public A setToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public A addToExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items);
  public A addAllToExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items);
  public A removeFromExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items);
  public A removeAllFromExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items);
  public A removeMatchingFromExtensions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExtensions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> getExtensions();
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> buildExtensions();
  public io.fabric8.kubernetes.api.model.NamedExtension buildExtension(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NamedExtension buildFirstExtension();
  public io.fabric8.kubernetes.api.model.NamedExtension buildLastExtension();
  public io.fabric8.kubernetes.api.model.NamedExtension buildMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public java.lang.Boolean hasMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public A withExtensions(java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> extensions);
  public A withExtensions(io.fabric8.kubernetes.api.model.NamedExtension... extensions);
  public java.lang.Boolean hasExtensions();
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> addNewExtension();
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> addNewExtensionLike(io.fabric8.kubernetes.api.model.NamedExtension item);
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> setNewExtensionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> editExtension(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> editFirstExtension();
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> editLastExtension();
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> editMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public interface ExtensionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NamedExtensionFluent<io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<N>>{
    public N and();
    public N endExtension();
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/PreferencesFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PreferencesFluent<A extends io.fabric8.kubernetes.api.model.PreferencesFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Boolean getColors();
  public A withColors(java.lang.Boolean colors);
  public java.lang.Boolean hasColors();
  public A addToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public A setToExtensions(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public A addToExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items);
  public A addAllToExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items);
  public A removeFromExtensions(io.fabric8.kubernetes.api.model.NamedExtension... items);
  public A removeAllFromExtensions(java.util.Collection<io.fabric8.kubernetes.api.model.NamedExtension> items);
  public A removeMatchingFromExtensions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildExtensions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> getExtensions();
  public java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> buildExtensions();
  public io.fabric8.kubernetes.api.model.NamedExtension buildExtension(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.NamedExtension buildFirstExtension();
  public io.fabric8.kubernetes.api.model.NamedExtension buildLastExtension();
  public io.fabric8.kubernetes.api.model.NamedExtension buildMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public java.lang.Boolean hasMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public A withExtensions(java.util.List<io.fabric8.kubernetes.api.model.NamedExtension> extensions);
  public A withExtensions(io.fabric8.kubernetes.api.model.NamedExtension... extensions);
  public java.lang.Boolean hasExtensions();
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> addNewExtension();
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> addNewExtensionLike(io.fabric8.kubernetes.api.model.NamedExtension item);
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> setNewExtensionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.NamedExtension item);
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> editExtension(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> editFirstExtension();
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> editLastExtension();
  public io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<A> editMatchingExtension(java.util.function.Predicate<io.fabric8.kubernetes.api.model.NamedExtensionBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ExtensionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.NamedExtensionFluent<io.fabric8.kubernetes.api.model.PreferencesFluent.ExtensionsNested<N>>{
    public N and();
    public N endExtension();
    
  }
  
}
